InMemorySender

Struct InMemorySender 

pub struct InMemorySender { /* private fields */ }
Shared in-memory message buffer that captures messages sent to each connection. Each connection_id maps to a list of messages that have been pushed to it.

Implementations

Source

impl InMemorySender

pub fn new() -> Self

pub async fn send( &self, connection_id: &str, message: Vec<u8>, ) -> Result<(), WsError>

pub async fn close(&self, connection_id: &str) -> Result<(), WsError>

pub async fn messages_for(&self, connection_id: &str) -> Vec<Vec<u8>>

pub async fn message_count(&self, connection_id: &str) -> usize

pub async fn total_message_count(&self) -> usize